<?php

/**
 * Implementation of hook_drush_command
 */
function ink_drush_command() {
  $items = array();

  $items['ink'] = array(
    'description' => 'Set up an Ink Ribbon starter kit.',
    'arguments' => array(
      'name' => 'A name for your theme.',
    ),
    'options' => array(
      'machinename' => '[a-z, 0-9] A machine-readable name for your theme.',
    ),
    'examples' => array(
      'drush ink "My theme name"',
    ),
  );

  return $items;
}

/**
 * Command: Set up an Ink Ribbon starter kit.
 */
function drush_ink($name = 'My theme') {

  $machine_name = drush_get_option('machinename');
  $machine_name = ($machine_name) ? $machine_name : preg_replace('/[^a-z0-9]+/', '', strtolower($name));

  // Get Ink Ribbon's location.
  $inkribbon_path = drush_locate_root() . '/' . drupal_get_path('theme', 'inkribbon');

  // It's in a sub dir, so navigate one up.
  $_inkribbon_path = split('/', $inkribbon_path);
  array_pop($_inkribbon_path);
  $inkribbon_path = join('/', $_inkribbon_path);

  // Construct the path where the sub theme will be created.
  array_pop($_inkribbon_path);
  $subtheme_path = join('/', $_inkribbon_path) . '/' . $machine_name;

  // Copy the starter kit and rename things where applicable.
  drush_op('ink_copy', $inkribbon_path . '/STARTERKIT', $subtheme_path, '/^(\.(\.)?|CVS|SVN|\.DS_Store|\.sass-cache)$/');
  drush_op('rename', $subtheme_path . '/STARTERKIT.info.txt', $subtheme_path . '/' . $machine_name . '.info');
  drush_op('ink_file_str_replace', $subtheme_path . '/' . $machine_name . '.info', 'name = STARTERKIT', 'name = ' . $name);

  // Notify user of the newly created theme.
  drush_print(dt('Starter kit for !name created in !path.',
    array(
      '!name' => $name,
      '!path' => $subtheme_path,
    )));
}

/**
 * Internal helper: Copy a directory recursively.
 */
function ink_copy($source_dir, $target_dir, $ignore = '/^\.(\.)?$/') {
  if (!is_dir($source_dir)) {
    drush_die(dt('The directory !directory was not found.', array('!directory' => $source_dir)));
  }
  $dir = opendir($source_dir);
  @mkdir($target_dir);
  while($file = readdir($dir)) {
    if (!preg_match($ignore, $file)) {
      if (is_dir($source_dir . '/' . $file)) {
        ink_copy($source_dir . '/' . $file, $target_dir . '/' . $file, $ignore);
      }
      else {
        copy($source_dir . '/' . $file, $target_dir . '/' . $file);
      }
    }
  }
  closedir($dir);
}

/**
 * Internal helper: Replace strings in a file.
 */
function ink_file_str_replace($file_path, $find, $replace) {
  $file_contents = file_get_contents($file_path);
  $file_contents = str_replace($find, $replace, $file_contents);
  file_put_contents($file_path, $file_contents);
}
